@@ -30,6 +30,7 @@
 #include <GormCore/GormFontViewController.h>
 #include <GormCore/GormSetNameController.h>
 #include <GormCore/GormFunctions.h>
+#include <GormCore/GormPluginManager.h>
 #include <GNUstepBase/GSObjCRuntime.h>
 #include <GormPrefs/GormPrefController.h>
 
@@ -39,6 +40,7 @@
   GormClassManager	*classManager;
   GormInspectorsManager	*inspectorsManager;
   GormPalettesManager	*palettesManager;
+  GormPluginManager	*pluginManager;
   id<IBSelectionOwners>	selectionOwner;
   NSMutableArray	*documents;
   BOOL			isConnecting;
@@ -56,11 +58,7 @@
   NSImage               *gormImage;
   NSImage               *testingImage;
   id			connectSource;
-  NSWindow		*connectSWindow;
-  NSRect		connectSRect;
   id			connectDestination;
-  NSWindow		*connectDWindow;
-  NSRect		connectDRect;
   NSPoint               cascadePoint;
   NSMutableArray        *testingWindows;
   NSSet                 *topObjects;
@@ -137,10 +135,12 @@
 	}
 
       /*
-       * Make sure the palettes manager exists, so that the editors and
-       * inspectors provided in the standard palettes are available.
+       * Make sure the palettes/plugins managers exist, so that the 
+       * editors and inspectors provided in the standard palettes 
+       * are available.
        */
       [self palettesManager];
+      [self pluginManager];
 
       /*
        * set the delegate.
@@ -959,6 +959,15 @@
   return palettesManager;
 }
 
+- (GormPluginManager*) pluginManager
+{
+  if (pluginManager == nil)
+    {
+      pluginManager = [[GormPluginManager alloc] init];
+    }
+  return pluginManager;
+}
+
 - (id<IBSelectionOwners>) selectionOwner
 {
   return (id<IBSelectionOwners>)selectionOwner;
@@ -1243,20 +1252,6 @@
   return classMenu;
 }
 
-- (void) unhide: (id)sender
-{
-  [super unhide: sender];
-  if(!isTesting)
-    {
-      id document = [self activeDocument];
-      id window = [document window];
-      [(GormDocument *)document setDocumentActive: NO];
-      [(GormDocument *)document setDocumentActive: YES];
-      [window orderFront: sender];
-      [[self mainMenu] display];
-    }
-}
-
 - (BOOL) documentNameIsUnique: (NSString *)filename
 {
   NSEnumerator *en = [documents objectEnumerator];
@@ -1275,4 +1270,9 @@
   
   return unique;
 }
+
+- (void) print: (id) sender
+{
+  [[self keyWindow] print: sender];
+}
 @end
