@@ -64,7 +64,7 @@ static NSImage *horizontalImage;
     }
   else
     {
-      return @"GormViewEditor";
+      return @"GormViewWithSubviewsEditor";
     }
 }
 
@@ -139,8 +139,6 @@ static NSImage *horizontalImage;
 	}
       else if ([[superview window] contentView] == _editedObject) 
 	{
-	  // NSRect frame = [_editedObject frame];
-	  // [self setFrame: frame];
 	  [[superview window] setContentView: self];
 	}
       else if ([superview isKindOfClass: [NSClipView class]])
@@ -649,252 +647,6 @@ static NSImage *horizontalImage;
   }
 }
 
-
-
-- (unsigned) draggingEntered: (id<NSDraggingInfo>)sender
-{
-  NSRect rect = [_editedObject bounds];
-  NSPoint loc = [sender draggingLocation];
-  NSPasteboard	*dragPb;
-  NSArray	*types;
-  
-  dragPb = [sender draggingPasteboard];
-  types = [dragPb types];
-  loc = [_editedObject convertPoint: loc fromView: nil];
-
-  if ([types containsObject: GormLinkPboardType] == YES)
-    {
-      return [parent draggingEntered: sender];
-    }
-
-  if (NSMouseInRect(loc, [_editedObject bounds], NO) == NO)
-    {
-      return NSDragOperationNone;
-    }
-  else
-    {
-      rect.origin.x += 3;
-      rect.origin.y += 2;
-      rect.size.width -= 5;
-      rect.size.height -= 5;
-      
-      [_editedObject lockFocus];
-      
-      [[NSColor darkGrayColor] set];
-      NSFrameRectWithWidth(rect, 2);
-      
-      [_editedObject unlockFocus];
-      [[self window] flushWindow];
-      return NSDragOperationCopy;
-    }
-}
-
-- (void) draggingExited: (id<NSDraggingInfo>)sender
-{
-  NSPasteboard	*dragPb;
-  NSArray	*types;
-  NSRect         rect;
-
-  dragPb = [sender draggingPasteboard];
-  types = [dragPb types];
-  
-  if ([types containsObject: GormLinkPboardType] == YES)
-    {
-      [parent draggingExited: sender];
-      return;
-    }
-
-
-  rect = [_editedObject bounds];
-  rect.origin.x += 3;
-  rect.origin.y += 2;
-  rect.size.width -= 5;
-  rect.size.height -= 5;
- 
-  rect.origin.x --;
-  rect.size.width ++;
-  rect.size.height ++;
-
-  [[self window] disableFlushWindow];
-  [self displayRect: 
-	  [_editedObject convertRect: rect
-			 toView: self]];
-  [[self window] enableFlushWindow];
-  [[self window] flushWindow];
-}
-
-- (unsigned int) draggingUpdated: (id<NSDraggingInfo>)sender
-{
-  NSPoint loc = [sender draggingLocation];
-  NSRect rect = [_editedObject bounds];
-  NSPasteboard	*dragPb;
-  NSArray	*types;
-  
-  dragPb = [sender draggingPasteboard];
-  types = [dragPb types];
-  loc = [_editedObject 
-	  convertPoint: loc fromView: nil];
-
-  if ([types containsObject: GormLinkPboardType] == YES)
-    {
-      return [parent draggingUpdated: sender];
-    }
-
-  rect.origin.x += 3;
-  rect.origin.y += 2;
-  rect.size.width -= 5;
-  rect.size.height -= 5;
-
-  if (NSMouseInRect(loc, [_editedObject bounds], NO) == NO)
-    {
-      [[self window] disableFlushWindow];
-      rect.origin.x --;
-      rect.size.width ++;
-      rect.size.height ++;
-      [self displayRect: 
-	      [_editedObject convertRect: rect
-			     toView: self]];
-      [[self window] enableFlushWindow];
-      [[self window] flushWindow];
-      return NSDragOperationNone;
-    }
-  else
-    {
-      [_editedObject lockFocus];
-      
-      [[NSColor darkGrayColor] set];
-      NSFrameRectWithWidth(rect, 2);
-      
-      [_editedObject unlockFocus];
-      [[self window] flushWindow];
-      return NSDragOperationCopy;
-    }
-}
-
-
-- (BOOL) prepareForDragOperation: (id<NSDraggingInfo>)sender
-{
-  NSString		*dragType;
-  NSArray *types;
-  NSPasteboard		*dragPb;
-
-  dragPb = [sender draggingPasteboard];
-
-  types = [dragPb types];
-  
-  if ([types containsObject: IBViewPboardType] == YES)
-    {
-      dragType = IBViewPboardType;
-    }
-  else if ([types containsObject: GormLinkPboardType] == YES)
-    {
-      dragType = GormLinkPboardType;
-      return [parent prepareForDragOperation: sender];
-    }
-  else
-    {
-      dragType = nil;
-    }
-
-  if (dragType == IBViewPboardType)
-    {
-      /*
-       * We can accept views dropped anywhere.
-       */
-      NSPoint		loc = [sender draggingLocation];
-      loc = [_editedObject  
-	      convertPoint: loc fromView: nil];
-      if (NSMouseInRect(loc, [_editedObject bounds], NO) == NO)
-	{
-	  return NO;
-	}
-      
-      return YES;
-    }
-  
-  return NO;
-}
-
-- (BOOL) performDragOperation: (id<NSDraggingInfo>)sender
-{
-  NSString		*dragType;
-  NSPasteboard		*dragPb;
-  NSArray *types;
-
-  dragPb = [sender draggingPasteboard];
-
-  types = [dragPb types];
-  
-  if ([types containsObject: IBViewPboardType] == YES)
-    {
-      dragType = IBViewPboardType;
-    }
-  else if ([types containsObject: GormLinkPboardType] == YES)
-    {
-      dragType = GormLinkPboardType;
-    }
-  else
-    {
-      dragType = nil;
-    }
-
-  if (dragType == IBViewPboardType)
-    {
-      NSPoint		loc = [sender draggingLocation];
-      NSArray		*views;
-      NSEnumerator	*enumerator;
-      NSView		*sub;
-
-      /*
-       * Ask the document to get the dragged views from the pasteboard and add
-       * them to it's collection of known objects.
-       */
-      views = [document pasteType: IBViewPboardType
-		   fromPasteboard: dragPb
-			   parent: _editedObject];
-      /*
-       * Now make all the views subviews of ourself, setting their origin to
-       * be the point at which they were dropped (converted from window
-       * coordinates to our own coordinates).
-       */
-      loc = [_editedObject convertPoint: loc fromView: nil];
-      if (NSMouseInRect(loc, [_editedObject bounds], NO) == NO)
-	{
-	  // Dropped outside our view frame
-	  NSLog(@"Dropped outside current edit view");
-	  dragType = nil;
-	  return NO;
-	}
-      enumerator = [views objectEnumerator];
-      while ((sub = [enumerator nextObject]) != nil)
-	{
-	  NSRect	rect = [sub frame];
-	  
-	  rect.origin = [_editedObject
-			  convertPoint: [sender draggedImageLocation]
-			  fromView: nil];
-	  rect.origin.x = (int) rect.origin.x;
-	  rect.origin.y = (int) rect.origin.y;
-	  rect.size.width = (int) rect.size.width;
-	  rect.size.height = (int) rect.size.height;
-	  [sub setFrame: rect];
-
-	  [_editedObject addSubview: sub];
-	  
-	  {
-	    id editor;
-	    editor = [document editorForObject: sub 
-			       inEditor: self 
-			       create: YES];
-	    [self selectObjects: 
-		    [NSArray arrayWithObject: editor]];
-	  }
-	}
-    }
-
-  return YES;
-}
-
 - (void) pasteInSelection
 {
   [self pasteInView: _editedObject];
