@@ -10,7 +10,7 @@
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
@@ -167,6 +167,7 @@ static NSImage	*dragImage = nil;
 - (void) mouseDown: (NSEvent*)theEvent
 {
   NSPoint	dragPoint = [theEvent locationInWindow];
+  NSWindow	*w = [self window];
   NSView	*view;
   GormDocument	*active = (GormDocument *)[(id<IB>)NSApp activeDocument];
   NSRect	rect;
@@ -201,12 +202,25 @@ static NSImage	*dragImage = nil;
 
   RELEASE(dragImage);
   dragImage = [[NSImage alloc] init];
-  rep = [[NSCachedImageRep alloc] initWithWindow: [self window]
-					    rect: rect];
   [dragImage setSize: rect.size];
+  rep = [[NSCachedImageRep alloc] initWithSize: rect.size
+					 depth: [w depthLimit]
+				      separate: YES
+					 alpha: [w alphaValue]>0.0 ? YES : NO];
   [dragImage addRepresentation: rep];
   RELEASE(rep);
 
+  /* Copy the contents of the clicked view from our window into the
+   * cached image representation.
+   * NB. We use lockFocusOnRepresentation: for this because it sets
+   * up cached image representation information in the image, and if
+   * that's not done before our copy, the image will overwrite our
+   * copied data when asked to draw the representation.
+   */
+  [dragImage lockFocusOnRepresentation: rep];
+  NSCopyBits([w gState], rect, NSZeroPoint);
+  [dragImage unlockFocus];
+
   type = [IBPalette typeForView: view];
   obj = [IBPalette objectForView: view];
   pb = [NSPasteboard pasteboardWithName: NSDragPboard];
