@@ -304,7 +304,7 @@ static BOOL currently_displaying = NO;
       
       // if this window is nil when the editor is created, we know it's a
       // standalone view.
-      if([anObject window] == nil)
+      if([anObject window] == nil && [anObject superview] == nil)
 	{
 	  NSDebugLog(@"#### Stand alone view: %@",_editedObject);
 	  viewWindow = [[GormViewWindow alloc] initWithView: _editedObject];
