@@ -167,10 +167,10 @@
 		   backing: NSBackingStoreBuffered
 		   defer: YES];
  
-  [win setMenu: self];
+  // [win setMenu: self];
   [win setLevel: NSSubmenuWindowLevel];
   [win setExcludedFromWindowsMenu: YES];
-  RETAIN(win); // FIXME: Argh..  this may leak.. temporary fix.
+  // RETAIN(win); // FIXME: Argh..  this may leak.. temporary fix.
 
   return win;
 }
