@@ -4,8 +4,7 @@
 
    Author: Gregory John Casamento <greg_casamento@yahoo.com>
    Date: 2003
-   Adapted from GormNSWindow.m
-   
+   (Adapted from GormNSWindow.m)
    This file is part of GNUstep.
    
    This program is free software; you can redistribute it and/or modify
@@ -24,10 +23,12 @@
 */
 
 #include <AppKit/AppKit.h>
-#include <GNUstepGUI/GSNibTemplates.h>
 #include <InterfaceBuilder/InterfaceBuilder.h>
+#include <GNUstepGUI/GSGormLoading.h>
 #include "GormNSPanel.h"
 
+
+// the default style mask we start with.
 static unsigned int defaultStyleMask = NSTitledWindowMask | NSClosableWindowMask
 		  | NSResizableWindowMask | NSMiniaturizableWindowMask;
 
@@ -47,6 +48,21 @@ static unsigned int defaultStyleMask = NSTitledWindowMask | NSClosableWindowMask
   [self setReleasedWhenClosed: NO];
 }
 
+- (id) initWithCoder: (NSCoder *)coder
+{
+  self = [super initWithCoder: coder];
+  if (self == nil)
+    {
+      return nil;
+    }
+  
+  // preserve the setting and set the actual window to NO.
+  _gormReleasedWhenClosed = [self isReleasedWhenClosed];
+  [self setReleasedWhenClosed: NO];
+  
+  return self;
+}
+
 - (id) initWithContentRect: (NSRect)contentRect
 		 styleMask: (unsigned int)aStyle
 		   backing: (NSBackingStoreType)bufferingType
