@@ -35,7 +35,7 @@
 #include "GormNumberFormatterAttributesInspector.h"
 
 /* this macro makes sure that the string contains a value, even if @"" */
-#define VSTR(str) ({id _str = str; (_str) ? _str : @"";})
+#define VSTR(str) ({id _str = (id)str; (_str) ? (id)_str : (id)(@"");})
 
 extern NSArray *predefinedNumberFormats;
 
